@@ -12,7 +12,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
 #
 # The developers of the Exaile media player hereby grant permission
@@ -34,6 +34,7 @@
 import logging
 import logging.handlers
 import os
+import platform
 import sys
 
 try:
@@ -163,7 +164,7 @@ class Exaile(object):
             Initializes Exaile
         """
         # pylint: disable-msg=W0201
-        logger.info("Loading Exaile %s..." % __version__)
+        logger.info("Loading Exaile %s on Python %s..." % (__version__, platform.python_version()))
 
         logger.info("Loading settings...")
         try:
@@ -171,6 +172,8 @@ class Exaile(object):
         except common.VersionError:
             common.log_exception(log=logger)
             exit(1)
+            
+        logger.debug("Settings loaded from %s" % settings.location)
 
         splash = None
 
